summaryrefslogtreecommitdiffstats
path: root/kopete/plugins/nowlistening/nowlisteningplugin.h
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/plugins/nowlistening/nowlisteningplugin.h')
-rw-r--r--kopete/plugins/nowlistening/nowlisteningplugin.h16
1 files changed, 8 insertions, 8 deletions
diff --git a/kopete/plugins/nowlistening/nowlisteningplugin.h b/kopete/plugins/nowlistening/nowlisteningplugin.h
index 7a608fd2..848b8aef 100644
--- a/kopete/plugins/nowlistening/nowlisteningplugin.h
+++ b/kopete/plugins/nowlistening/nowlisteningplugin.h
@@ -23,7 +23,7 @@
#include "kopeteplugin.h"
-#include <qptrlist.h>
+#include <tqptrlist.h>
namespace Kopete { class ChatSession; class Message; }
@@ -41,12 +41,12 @@ class NowListeningPlugin : public Kopete::Plugin
friend class NowListeningGUIClient;
public:
- NowListeningPlugin( QObject *parent, const char *name, const QStringList &args );
+ NowListeningPlugin( TQObject *parent, const char *name, const TQStringList &args );
virtual ~NowListeningPlugin();
static NowListeningPlugin* plugin();
public slots:
- void slotMediaCommand( const QString &, Kopete::ChatSession *theChat );
+ void slotMediaCommand( const TQString &, Kopete::ChatSession *theChat );
void slotOutgoingMessage(Kopete::Message&);
void slotAdvertCurrentMusic();
@@ -57,17 +57,17 @@ friend class NowListeningGUIClient;
* useful to set it to false if one already has called
* update somewhere else, for instance in newTrackPlaying().
*/
- QString mediaPlayerAdvert(bool update = true);
+ TQString mediaPlayerAdvert(bool update = true);
/**
* @internal Build the message for @ref mediaPlayerAdvert
* @param message Reference to the messsage, because return QString cause data loss.
* @param player Pointer to the current Media Player.
* Used to get the information about the current track playing.
* @param update Whether the players must update their data. It can be
* useful to set it to false if one already has called
* update somewhere else, for instance in newTrackPlaying().
*/
- void buildTrackMessage(QString &message, NLMediaPlayer *player, bool update);
+ void buildTrackMessage(TQString &message, NLMediaPlayer *player, bool update);
/**
* @return true if one of the players has changed track since the last message.
*/
@@ -78,11 +78,11 @@ friend class NowListeningGUIClient;
* @p in - the source format string
* @p bool - is this call within a set of brackets for conditional expansion?
*/
- QString substDepthFirst( NLMediaPlayer *player, QString in, bool inBrackets) const;
+ TQString substDepthFirst( NLMediaPlayer *player, TQString in, bool inBrackets) const;
/**
* Sends a message to a single chat
*/
- void advertiseToChat( Kopete::ChatSession* theChat, QString message );
+ void advertiseToChat( Kopete::ChatSession* theChat, TQString message );
/**
* Update the currentMedia pointer on config change.
*/
@@ -57,17 +57,17 @@ friend class NowListeningGUIClient;
/**
* @internal Build the message for @ref mediaPlayerAdvert
- * @param message Reference to the messsage, because return QString cause data loss.
+ * @param message Reference to the messsage, because return TQString cause data loss.
* @param player Pointer to the current Media Player.
* Used to get the information about the current track playing.